<?php // Contact Form X Reset Settings

if (!defined('ABSPATH')) exit;

function contactformx_admin_notice() {
	
	$screen = get_current_screen();
	
	if (!property_exists($screen, 'id')) return;
	
	if ($screen->id === 'settings_page_contactformx') {
		
		if (isset($_GET['reset-options'])) {
			
			if ($_GET['reset-options'] === 'true') : ?>
				
				<div class="notice notice-success is-dismissible"><p><strong><?php esc_html_e('Default options restored.', 'contact-form-x'); ?></strong></p></div>
				
			<?php else : ?>
				
				<div class="notice notice-info is-dismissible"><p><strong><?php esc_html_e('No changes made.', 'contact-form-x'); ?></strong></p></div>
				
			<?php endif;
			
		}
		
		if (isset($_GET['reset-widget'])) {
			
			if ($_GET['reset-widget'] === 'true') : ?>
				
				<div class="notice notice-success is-dismissible"><p><strong><?php esc_html_e('All email data deleted.', 'contact-form-x'); ?></strong></p></div>
				
			<?php else : ?>
				
				<div class="notice notice-info is-dismissible"><p><strong><?php esc_html_e('No changes made.', 'contact-form-x'); ?></strong></p></div>
				
			<?php endif;
			
		}
		
		if (isset($_GET['drop-table'])) {
			
			if ($_GET['drop-table'] === 'true') : ?>
				
				<div class="notice notice-success is-dismissible"><p><strong><?php esc_html_e('CFX table removed from database.', 'contact-form-x'); ?></strong></p></div>
				
			<?php else : ?>
				
				<div class="notice notice-info is-dismissible"><p><strong><?php esc_html_e('No changes made.', 'contact-form-x'); ?></strong></p></div>
				
			<?php endif;
			
		}
		
		if (isset($_GET['delete-recipient'])) {
			
			if ($_GET['delete-recipient'] === 'true') : ?>
				
				<div class="notice notice-success is-dismissible"><p><strong><?php esc_html_e('Recipient Deleted.', 'contact-form-x'); ?></strong></p></div>
				
			<?php else : ?>
				
				<div class="notice notice-info is-dismissible"><p><strong><?php esc_html_e('No changes made.', 'contact-form-x'); ?></strong></p></div>
				
			<?php endif;
			
		}
		
	}
	
}

function contactformx_reset_options() {
	
	if (isset($_GET['reset-options-verify']) && wp_verify_nonce($_GET['reset-options-verify'], 'contactformx_reset_options')) {
		
		if (!current_user_can('manage_options')) exit;
		
		$sections = array('email', 'form', 'customize', 'appearance', 'advanced');
		
		foreach ($sections as $section) {
			
			$default = contactformx_options($section);
			
			${'delete_'. $section} = delete_option('contactformx_'. $section);
			
		}
		
		$result = 'false';
		
		foreach ($sections as $section) {
			
			if (${'delete_'. $section}) {
				
				$result = 'true';
				
			}
			
		}
		
		$location = admin_url('options-general.php?page=contactformx&reset-options='. $result);
		
		wp_redirect($location);
		
		exit;
		
	}
	
}

function contactformx_reset_widget() {
	
	if (isset($_GET['reset-widget-verify']) && wp_verify_nonce($_GET['reset-widget-verify'], 'contactformx_reset_widget')) {
		
		if (!current_user_can('manage_options')) exit;
		
		$result = false;
		
		$emails = get_posts(array('post_type' => 'cfx_email', 'post_status' => 'any', 'posts_per_page' => -1));
		
		foreach ($emails as $email) $result = wp_delete_post($email->ID, true);
		
		$result = $result ? 'true' : 'false';
		
		$location = admin_url('options-general.php?page=contactformx&tab=tab5&reset-widget='. $result);
		
		wp_redirect($location);
		
		exit;
		
	}
	
}

function contactformx_reset_widget_legacy() {
	
	if (isset($_GET['reset-widget-verify-legacy']) && wp_verify_nonce($_GET['reset-widget-verify-legacy'], 'contactformx_reset_widget_legacy')) {
		
		if (!current_user_can('manage_options')) exit;
		
		global $wpdb;
		
		$table = $wpdb->prefix .'cfx_email';
		
		$delete = $wpdb->query("TRUNCATE TABLE ". $table);
		
		$result = $delete ? 'true' : 'false';
		
		$location = admin_url('options-general.php?page=contactformx&tab=tab5&reset-widget='. $result);
		
		wp_redirect($location);
		
		exit;
		
	}
	
}

function contactformx_drop_table_legacy() {
	
	if (isset($_GET['drop-table-verify-legacy']) && wp_verify_nonce($_GET['drop-table-verify-legacy'], 'contactformx_drop_table_legacy')) {
		
		if (!current_user_can('manage_options')) exit;
		
		global $wpdb;
		
		$table = $wpdb->prefix .'cfx_email';
		
		$delete = $wpdb->query("DROP TABLE IF EXISTS ". $table);
		
		$result = $delete ? 'true' : 'false';
		
		$location = admin_url('options-general.php?page=contactformx&tab=tab5&drop-table='. $result);
		
		wp_redirect($location);
		
		exit;
		
	}
	
}

function contactformx_delete_recipient() {
	
	if (isset($_GET['delete-recipient-verify']) && wp_verify_nonce($_GET['delete-recipient-verify'], 'contactformx_delete_recipient')) {
		
		if (!current_user_can('manage_options')) exit;
		
		$id = isset($_GET['recipient']) ? $_GET['recipient'] : null;
		
		$options = contactformx_options('email');
		
		if (isset($options['recipient-'. $id])) unset($options['recipient-'. $id]);
		
		if (isset($options['number-recipients'])) {
			
			$options['number-recipients'] = (string) --$options['number-recipients'];
			
			if (intval($options['number-recipients']) <= 0) $options['number-recipients'] = '1';
			
		} else {
			
			$options['number-recipients'] = '1';
			
		}
		
		$update = update_option('contactformx_email', $options);
		
		$result = $update ? 'true' : 'false';
		
		$location = admin_url('options-general.php?page=contactformx&delete-recipient='. $result);
		
		wp_redirect($location);
		
		exit;
		
	}
	
}
